%global pkg_name zlib

%bcond_without doc
%bcond_without prof
%bcond_without shared

# ghc does not emit debug information
%global debug_package %{nil}

Name:           ghc-%{pkg_name}
# part of haskell-platform-2009.2.0.2
Version:        0.5.0.0
Release:        11%{?dist}
Summary:        Haskell compression and decompression library binding

Group:          Development/Libraries
License:        BSD
URL:            http://hackage.haskell.org/cgi-bin/hackage-scripts/package/%{pkg_name}
Source0:        http://hackage.haskell.org/packages/archive/%{pkg_name}/%{version}/%{pkg_name}-%{version}.tar.gz
# fedora ghc archs:
ExclusiveArch:  %{ix86} x86_64 ppc alpha
BuildRequires:  ghc, ghc-rpm-macros >= 0.3.1
%if %{with doc}
BuildRequires:  ghc-doc
%endif
%if %{with prof}
BuildRequires:  ghc-prof
%endif
BuildRequires:  zlib-devel

%description
This package provides a pure Haskell interface for compressing and
decompressing streams of data represented as lazy ByteStrings. It uses
the zlib C library so it has high performance. It supports the "zlib",
"gzip" and "raw" compression formats.

It provides a convenient high level API suitable for most tasks.  For
the few cases where more control is needed, it provides access to the
full zlib feature set.

%package devel
Summary:        Haskell %{pkg_name} library
Group:          Development/Libraries
Requires:       ghc = %{ghc_version}
Requires(post): ghc = %{ghc_version}
Requires(postun): ghc = %{ghc_version}
%if %{with shared}
Requires:       %{name} = %{version}-%{release}
%endif
Requires:       zlib-devel

%description devel
This package contains the development files for %{name}
built for ghc-%{ghc_version}.


%if %{with doc}
%package doc
Summary:        Documentation for %{name}
Group:          Development/Libraries
Requires:       ghc-doc = %{ghc_version}
Requires(post): ghc-doc = %{ghc_version}
Requires(postun): ghc-doc = %{ghc_version}

%description doc
This package contains development documentation files for the %{name} library.
%endif


%if %{with prof}
%package prof
Summary:        Profiling libraries for %{name}
Group:          Development/Libraries
Requires:       %{name}-devel = %{version}-%{release}
Requires:       ghc-prof = %{ghc_version}

%description prof
This package contains profiling libraries for %{name}
built for ghc-%{ghc_version}.
%endif


%prep
%setup -q -n %{pkg_name}-%{version}


%build
%cabal_configure --ghc %{?with_prof:-p}
%cabal build
%if %{with doc}
%cabal haddock
%endif


%install
%cabal_install
%cabal_pkg_conf

%ghc_gen_filelists %{name}


%clean
rm -rf $RPM_BUILD_ROOT


%post devel
ghc-pkg recache


%if %{with doc}
%post doc
%ghc_reindex_haddock
%endif


%postun devel
ghc-pkg recache


%if %{with doc}
%postun doc
if [ "$1" -eq 0 ] ; then
  %ghc_reindex_haddock
fi
%endif


%if %{with shared}
%files -f %{name}.files
%defattr(-,root,root,-)
%{_docdir}/%{name}-%{version}
%endif


%files devel -f %{name}-devel.files
%defattr(-,root,root,-)
%{_docdir}/%{name}-%{version}


%if %{with doc}
%files doc -f %{name}-doc.files
%defattr(-,root,root,-)
%endif


%if %{with prof}
%files prof -f %{name}-prof.files
%defattr(-,root,root,-)
%endif


%changelog
* Wed Dec 16 2009 Jens Petersen <petersen@redhat.com> - 0.5.0.0-11
- build for ghc-6.12.1
- added shared library support: needs ghc-rpm-macros 0.3.1
- use cabal_pkg_conf to generate package.conf.d file and use ghc-pkg recache

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0.0-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Sat May 16 2009 Jens Petersen <petersen@redhat.com> - 0.5.0.0-9
- buildrequires ghc-rpm-macros (cabal2spec-0.16)

* Fri Apr 24 2009 Jens Petersen <petersen@redhat.com> - 0.5.0.0-8
- sync with cabal2spec-0.14

* Fri Feb 27 2009 Jens Petersen <petersen@redhat.com> - 0.5.0.0-7
- update to cabal2spec-0.11:
- add devel subpackage
- use ix86 macro for archs and add alpha
- use global rather than define
- make devel subpackage own docdir for now

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.5.0.0-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Feb  9 2009 Jens Petersen <petersen@redhat.com> - 0.5.0.0-5
- rebuild to fix unexpanded post preun macros
- add doc subpackage and BR ghc-doc
- add doc requires(post) ghc-doc

* Mon Dec 22 2008 Jens Petersen <petersen@redhat.com> - 0.5.0.0-4
- use bcond for doc and prof build flags (Till Maas, #426751)

* Mon Dec  1 2008 Jens Petersen <petersen@redhat.com> - 0.5.0.0-3
- sync with lib template:
  - add build_prof and build_doc
  - prof requires main package
  - update scriptlet macro names

* Tue Nov 25 2008 Jens Petersen <petersen@redhat.com> - 0.5.0.0-2
- build with ghc-6.10.1
- no longer buildrequire haddock09
- provide devel
- add exclusivearch for current ghc archs
- reindex haddock docs only when uninstalling in postun

* Tue Nov 11 2008 Bryan O'Sullivan <bos@serpentine.com> - 0.5.0.0-1
- Update to 0.5.0.0

* Thu Oct 23 2008 Jens Petersen <petersen@redhat.com> - 0.4.0.4-2
- update for current rawhide
- add pkg_docdir and remove hsc_name
- use haddock09

* Tue Oct 14 2008 Bryan O'Sullivan <bos@serpentine.com> - 0.4.0.4-1
- Revised to follow Haskell packaging guidelines

* Sun Feb 17 2008 Yaakov Nemoy <haskell.rpms@hexago.nl> - 0.4.0.2-1
- added in url

* Sun Feb 17 2008 cabal-rpm <cabal-devel@haskell.org> - 0.4.0.2-1
- spec file autogenerated by cabal-rpm
